fnss.topologies.topology.DirectedTopology.in_edges_iter — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.6.1 documentation »

# fnss.topologies.topology.DirectedTopology.in_edges_iter

`DirectedTopology.` `in_edges_iter`(nbunch=None, data=False)

  Return an iterator over the incoming edges.

  Parameters: | nbunch : iterable container, optional (default= all nodes) A container of nodes. The container will be iterated through once. data : bool, optional (default=False) If True, return edge attribute dict in 3-tuple (u,v,data).
  Returns: | in_edge_iter : iterator An iterator of (u,v) or (u,v,d) tuples of incoming edges.

  See also

  `edges_iter`
    return an iterator of edges

### Navigation

- index
- modules |
- modules |
- FNSS 0.6.1 documentation »